<div align="center">

# Rin-Exceptions

![Rin](https://raw.githubusercontent.com/No767/Rin/dev/assets/Rin%20Logo%20V4%20(GitHub).png)


![PyPI](https://img.shields.io/pypi/v/rin-exceptions?label=PyPi&logo=pypi&logoColor=white) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/rin-exceptions?label=Python&logo=python&logoColor=white) ![PyPI - Downloads](https://img.shields.io/pypi/dd/rin-exceptions?label=PyPi%20Downloads&logo=pypi&logoColor=white) ![GitHub](https://img.shields.io/github/license/No767/Rin-Exceptions?label=License&logo=github)

A set of base exceptions for Rin

<div align="left">

# Info

This package is a set of base exceptions used by Rin. It's meant to contain custom exceptions that are used by Rin, and in turn, Kumiko.

# Installation

pip: 

```sh
pip install rin-exceptions
```

poetry:

```sh
poetry add rin-exceptions
```